@@ -33,7 +33,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
 
-  $Id: stdio.h 2427 2014-05-01 14:06:03Z amylaar $
+  $Id: stdio.h 2503 2016-02-07 22:59:47Z joerg_wunsch $
 */
 
 #ifndef _STDIO_H_
@@ -44,9 +44,11 @@
 #include <inttypes.h>
 #include <stdarg.h>
 
+#ifndef __DOXYGEN__
 #define __need_NULL
 #define __need_size_t
 #include <stddef.h>
+#endif	/* !__DOXYGEN__ */
 
 /** \file */
 /** \defgroup avr_stdio <stdio.h>: Standard IO facilities
@@ -941,10 +943,11 @@ static __inline__ int fflush(FILE *stream __attribute__((unused)))
 }
 #endif
 
-#if 1 /* ??? unimplemented  */
+#ifndef __DOXYGEN__
+/* only mentioned for libstdc++ support, not implemented in library */
 #define BUFSIZ 1024
 #define _IONBF 0
-typedef long long fpos_t;
+__extension__ typedef long long fpos_t;
 extern int fgetpos(FILE *stream, fpos_t *pos);
 extern FILE *fopen(const char *path, const char *mode);
 extern FILE *freopen(const char *path, const char *mode, FILE *stream);
@@ -961,7 +964,7 @@ extern void setbuf(FILE *stream, char *buf);
 extern int setvbuf(FILE *stream, char *buf, int mode, size_t size);
 extern FILE *tmpfile(void);
 extern char *tmpnam (char *s);
-#endif
+#endif	/* !__DOXYGEN__ */
 
 #ifdef __cplusplus
 }
@@ -969,6 +972,7 @@ extern char *tmpnam (char *s);
 
 /*@}*/
 
+#ifndef __DOXYGEN__
 /*
  * The following constants are currently not used by avr-libc's
  * stdio subsystem.  They are defined here since the gcc build
@@ -978,6 +982,8 @@ extern char *tmpnam (char *s);
 #define SEEK_CUR 1
 #define SEEK_END 2
 
+#endif
+
 #endif /* __ASSEMBLER */
 
 #endif /* _STDLIB_H_ */
