@@ -33,7 +33,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
 
-  $Id: stdlib.h 2443 2014-08-11 21:50:59Z joerg_wunsch $
+  $Id: stdlib.h 2503 2016-02-07 22:59:47Z joerg_wunsch $
 */
 
 #ifndef _STDLIB_H_
@@ -41,6 +41,7 @@
 
 #ifndef __ASSEMBLER__
 
+#ifndef __DOXYGEN__
 #define __need_NULL
 #define __need_size_t
 #define __need_wchar_t
@@ -49,6 +50,7 @@
 #ifndef __ptr_t
 #define __ptr_t void *
 #endif
+#endif	/* !__DOXYGEN__ */
 
 #ifdef __cplusplus
 extern "C" {
@@ -669,9 +671,12 @@ extern char *dtostrf(double __val, signed char __width,
 
 /*@}*/
 
+#ifndef __DOXYGEN__
+/* dummy declarations for libstdc++ compatibility */
 extern int atexit(void (*)(void));
 extern int system (const char *);
 extern char *getenv (const char *);
+#endif	/* __DOXYGEN__ */
 
 #ifdef __cplusplus
 }
